class afs::config(
  $cachesize = $afs::params::cachesize,
  $memcachesize = $afs::params::memcachesize,
  $options   = $afs::params::options,
  $runserver = $afs::params::runserver,
  $thiscell = $afs::params::thiscell,
  $is_upstream = $afs::params::is_upstream,
) inherits afs::params {

  # Merge with hiera hash first and with default options hash afterwards
  $tmp_merged_options = merge($afs::params::default_options, $afs::params::options, $options)
  if $tmp_merged_options['memcache'] {
    $merged_options = delete(delete(delete(delete($tmp_merged_options, 'stat'), 'files'), 'dcache'), 'chunksize')
  } else {
    $merged_options = $tmp_merged_options
  }

  if($thiscell == 'cern.ch' ) {  # not applicable for test cells.
    file{'/usr/vice/etc/CellServDB.local':
      ensure    => file,
      owner     => 'root',
      group     => 'root',
      mode      => '0644',
      show_diff => false,  # workaround for https://tickets.puppetlabs.com/browse/PUP-1441
      source    => 'puppet:///modules/afs/CellServDB.local',
      require   => Class['afs::install'],
      before    => Service['openafs-client'],
    }
    file{'/usr/vice/etc/CellServDB.dist':
      ensure    => file,
      owner     => 'root',
      group     => 'root',
      mode      => '0644',
      show_diff => false,  # workaround for https://tickets.puppetlabs.com/browse/PUP-1441
      source    => 'puppet:///modules/afs/CellServDB.dist',
      require   => Class['afs::install'],
      before    => Service['openafs-client'],
    }
  }

  file{'/usr/vice/etc/ThisCell':
    ensure  => 'file',
    owner   => 'root',
    group   => 'root',
    mode    => '0644',
    content => "${thiscell}\n",
    require => Class['afs::install'],
  }

  if $merged_options['memcache'] {
    if is_integer($memcachesize) {
      if $memcachesize + 0 > 4194304 { # max mem cache size is 4GB
        $my_cachesize = '4194304'
      } elsif $memcachesize + 0 < 10240 { # min cache size is 10MB
        $my_cachesize = '10240'
      } else {
        $my_cachesize = $memcachesize
      }
    } else {
      $my_cachesize = '262144'
    }
  } else {
    if $cachesize == 'AUTOMATIC' {
      if is_integer($::openafspartsize) and $::openafspartsize + 0 > 0 {
        $my_cachesize = sprintf('%i', 0.8 * $::openafspartsize)
      } else {
        $my_cachesize = '131072' # sensible default
      }
    } elsif is_integer($cachesize) {
      if $cachesize + 0 > 52428800 { # max cache size is 50GB
        $my_cachesize = '52428800'
      } elsif $cachesize + 0 < 131072 { # min cache size is 128MB
        $my_cachesize = '131072'
      } else {
        $my_cachesize = $cachesize
      }
    } else {
      $my_cachesize = '131072'
    }
  }

  $sysconfig_afs = $is_upstream ? {
    true    => '/etc/sysconfig/openafs',
    default => '/etc/sysconfig/afs'
  }

  file{$sysconfig_afs:
    ensure  => 'file',
    owner   => 'root',
    group   => 'root',
    mode    => '0644',
    content => template('afs/sysconfig-afs.erb'),
    require => Class['afs::install'],
  }

  file{'/usr/vice/etc/cacheinfo':
    ensure  => 'file',
    owner   => 'root',
    group   => 'root',
    mode    => '0644',
    content => "/afs:/usr/vice/cache:${my_cachesize}\n",
    require => Class['afs::install'],
  }
}
