class afs::service(
  $is_upstream = $afs::params::is_upstream,
) inherits afs::params  {

  # in openafs-1.6, the initscript for OpenAFS split into client &
  # server parts. The CERN OpenAFS version continued to use the old
  # 'afs' init script for the client on SLC5 and SLC6. Need to cope
  # with this.

  $afs_service = $is_upstream ? {
    true => 'openafs-client',
    default  => 'afs',
  }

  service { 'openafs-client':  # keep the upstream name as 'generic'
    ensure     => running,
    name       => $afs_service,
    hasstatus  => false,    # not on SLC6 init script, unreliable on CC7 systemd
    pattern    => ' \[afsd\]$', # cache manager kernel thread, shows as '[afsd]' in "ps -ef"
    hasrestart => false,    # generally a very bad idea
    stop       => '/bin/false',
    enable     => true,
    require    => [ Class['afs::config','afs::install'],
                    Package['openafs-client','cern-afs-setserverprefs'],
                  ],
  }
}
