require 'spec_helper'


describe 'afs', type: 'class' do
  ['6','7'].each do |number|
    context "with operatingsystemmajrelease at #{number}" do
      let(:hiera_config) { 'spec/hiera.yaml' }
      context "with openafsversion including cern" do
        let(:facts) do { 
          operatingsystemmajorrelease: "#{number}",
          operatingsystemmajrelease: "#{number}",
          os: { release: { major: "#{number}" } },
          operatingsystemrelease: "#{number}.3.4",
          openafsversion: "1.6.9-2.el7.cern",
          kernelrelease: '3.10.0-327.28.3.el7.x86_64'
        }
        end
        it { is_expected.to compile.with_all_deps }
        it { is_expected.to contain_package('openafs') }
        if number == '6' then
          it { is_expected.to contain_package('kernel-module-openafs-3.10.0-327.28.3.el7.x86_64') }
        else  
          it { is_expected.to contain_package('kmod-openafs') }
        end
        it { is_expected.to  contain_lemon__metric('46') }
        it { is_expected.to  contain_firewall('100 allow afs3-callback') }
        it { is_expected.to have_firewall_resource_count(1) }
      end
      context "with openafsversion not including cern" do
        let(:facts) do { 
          operatingsystemmajorrelease: "#{number}",
          operatingsystemmajrelease: "#{number}",
          os: { release: { major: "#{number}" } },
          operatingsystemrelease: "#{number}.3.4",
          openafsversion: "1.6.9-2.el7",
          kernelrelease: '3.10.0-327.28.3.el7.x86_64'
        }
        end
        it { is_expected.to compile.with_all_deps }
        it { is_expected.to contain_package('openafs') }
        it { is_expected.to contain_package('kmod-openafs') }
        it { is_expected.to contain_service('openafs-client') }
        it { is_expected.to contain_file('/etc/sysconfig/openafs').with_content(%r{^AFS_POST_INIT=/usr/bin/.*$}) }
        context 'with lemon_enable false' do
          let(:params) do {
             enable_lemon: false,
          }
          end
          it { is_expected.to compile.with_all_deps }
          it { is_expected.to have_lemon__metric_resource_count(0) }
        end
        context 'with enable_firewall false' do
          let(:params) do {
             enable_firewall: false,
          }
          end
          it { is_expected.to compile.with_all_deps }
          it { is_expected.to have_firewall_resource_count(0) }
        end
        context 'with memcache option set' do
          let(:params) do {
             memcachesize: '1234',
             options: { 'memcache' => true },
          }
          end
          it { is_expected.to compile.with_all_deps }
          it { is_expected.to contain_file('/etc/sysconfig/openafs').with_content(%r{^AFSD_ARGS=".*-memcache.*"$}) }
        end
      end
    end
  end
end
